<?xml version="1.0"?>


<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:bibxml="http://bibtexml.sf.net/"
                version="1.0">

    <!-- Bibtex entry types  -->
    <xsl:template match="bibxml:article">
          <p>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:journal"/>

            <xsl:choose>
                <xsl:when test="bibxml:volume != '' and (not(bibxml:number) or bibxml:number = '')">
                        <xsl:apply-templates select="bibxml:volume"/>
                </xsl:when>
                <xsl:when test="bibxml:volume != '' and bibxml:number != '' ">
                        <xsl:value-of select="bibxml:volume"/>
                        (<xsl:value-of select="bibxml:number"/>).
                </xsl:when>
                <!-- only a number, no volume -->
                <xsl:when test="bibxml:number != ''">
                        no.&#160;<xsl:apply-templates select="bibxml:number"/>.
                </xsl:when>
            </xsl:choose>
                <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:pages"/>

            <!-- Links to local and remote access -->
            <br></br>
            <xsl:apply-templates select="bibxml:pdf"/>
            <xsl:apply-templates select="bibxml:ps"/>
            <xsl:apply-templates select="bibxml:zip"/>
            <xsl:apply-templates select="bibxml:medline_pmid"/>
            <xsl:apply-templates select="bibxml:web"/>
          </p>

            <!-- Abstract -->
            <xsl:apply-templates select="bibxml:abstract"/>

            <!-- Keywords -->
            <p><blockquote><font size="-1">
              <xsl:apply-templates select="bibxml:keywords"/>
            </font></blockquote></p>
    </xsl:template>

    <xsl:template match="bibxml:inproceedings | bibxml:conference">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:apply-templates select="bibxml:booktitle"/>
            <xsl:if test="bibxml:organization != ''">
                    <xsl:value-of select="bibxml:organization"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:address"/>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:pages"/>
            <xsl:apply-templates select="bibxml:url"/>
    </xsl:template>

    <xsl:template match="bibxml:techreport">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:apply-templates select="bibxml:booktitle"/>
            <xsl:value-of select="bibxml:institution"/>.
            <xsl:if test="bibxml:number != ''">
                    <xsl:value-of select="bibxml:number"/>.
            </xsl:if>
            <xsl:if test="bibxml:type != ''">
                    <xsl:value-of select="bibxml:type"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:url"/>
    </xsl:template>

    <xsl:template match="bibxml:book">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:editor != ''">
                    <xsl:value-of select="bibxml:editor"/>.
            </xsl:if>
            <xsl:if test="bibxml:publisher != ''">
                    <xsl:value-of select="bibxml:publisher"/>.
            </xsl:if>
            <xsl:if test="bibxml:series != ''">
                    <xsl:value-of select="bibxml:series"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:volume"/>
            <xsl:apply-templates select="bibxml:edition"/>
            <xsl:apply-templates select="bibxml:address"/>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
    </xsl:template>

    <xsl:template match="bibxml:phdthesis | bibxml:masterthesis">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:school != ''">
                    <xsl:value-of select="bibxml:school"/>.
            </xsl:if>
            <xsl:if test="bibxml:number != ''">
                    <xsl:value-of select="bibxml:number"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:year"/>
    </xsl:template>

    <xsl:template match="bibxml:misc">
            <xsl:if test="bibxml:title != ''">
                    <xsl:apply-templates select="bibxml:title"/>
            </xsl:if>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:howpublished != ''">
                    <xsl:value-of select="bibxml:howpublished"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
    </xsl:template>

    <xsl:template match="bibxml:unpublished">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:apply-templates select="bibxml:note"/>
    </xsl:template>

    <xsl:template match="bibxml:manual">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:organization != ''">
                    <xsl:value-of select="bibxml:organization"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:edition"/>
            <xsl:apply-templates select="bibxml:address"/>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:note"/>
    </xsl:template>

    <xsl:template match="bibxml:proceedings">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:if test="bibxml:editor != ''">
                    <xsl:value-of select="bibxml:editor"/>.
            </xsl:if>
            <xsl:if test="bibxml:publisher != ''">
                    <xsl:value-of select="bibxml:publisher"/>.
            </xsl:if>
            <xsl:if test="bibxml:organization != ''">
                    <xsl:value-of select="bibxml:organization"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:address"/>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:note"/>
    </xsl:template>

    <xsl:template match="bibxml:booklet">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:howpublished != ''">
                    <xsl:value-of select="bibxml:howpublished"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:address"/>
            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:note"/>
    </xsl:template>


    <xsl:template match="bibxml:inbook">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:if test="bibxml:chapter != ''">
                    <xsl:value-of select="bibxml:chapter"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:editor != ''">
                    Editted by <xsl:value-of select="bibxml:editor"/>.
            </xsl:if>
            <xsl:if test="bibxml:howpublished != ''">
                    <xsl:value-of select="bibxml:howpublished"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:address"/>

            <xsl:if test="bibxml:publisher != ''">
                    <xsl:value-of select="bibxml:publisher"/>.
            </xsl:if>
            <xsl:if test="bibxml:series != ''">
                    <xsl:value-of select="bibxml:series"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:volume"/>
            <xsl:apply-templates select="bibxml:edition"/>

            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:pages"/>
    </xsl:template>


    <xsl:template match="bibxml:incollection">
            <xsl:apply-templates select="bibxml:title"/>
            <xsl:apply-templates select="bibxml:booktitle"/>
            <xsl:apply-templates select="bibxml:author"/>
            <xsl:if test="bibxml:editor != ''">
                    Editted by <xsl:value-of select="bibxml:editor"/>.
            </xsl:if>
            <xsl:apply-templates select="bibxml:address"/>

            <xsl:if test="bibxml:publisher != ''">
                    <xsl:value-of select="bibxml:publisher"/>.
            </xsl:if>

            <xsl:apply-templates select="bibxml:month"/>
            <xsl:apply-templates select="bibxml:year"/>
            <xsl:apply-templates select="bibxml:pages"/>
    </xsl:template>

    
    <!-- fields -->
    <xsl:template match="bibxml:pages">
            <xsl:if test=". != ''">
                 pp.&#160;<xsl:value-of select="."/>.
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:month">
            <xsl:if test=". != ''">
                    <xsl:value-of select="."/>&#160;</xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:volume">
            <xsl:if test=". != ''">	
                 vol.&#160;<xsl:value-of select="."/>.
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:edition">
            <xsl:if test=". != ''">	
                 ed.&#160;<xsl:value-of select="."/>.
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:title">
            <xsl:if test=". != ''">	
                     <b>"<xsl:value-of select="."/>" </b>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:note">
            <xsl:if test=". != ''">
                    <i>Note: </i>
                    <xsl:value-of select="."/>.
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:address">
            <xsl:if test=". != ''">	
                     <xsl:value-of select="."/>.
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:booktitle">
         <i><xsl:value-of select="."/></i>
         <xsl:if test="position() + 1 != last()">. </xsl:if>
    </xsl:template>
    
    <xsl:template match="bibxml:journal">
      <a href="../journal/{.}.html"><xsl:value-of select="."/></a>
         <xsl:if test="position() + 1 != last()">. </xsl:if>
    </xsl:template>
    
    <xsl:template match="bibxml:year">
            <xsl:if test=". != ''">
                <a href="../year/{.}.html">
                   <xsl:value-of select="."/>
                 </a>.
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:author">
            <a href="../author/{.}.html">
                <xsl:value-of select="."/>
            </a>
            <xsl:choose>
                <xsl:when test="position() = count(../bibxml:author)">. </xsl:when>
                <xsl:when test="count(../bibxml:author) = 2 and position() = 1"> and </xsl:when>
                <xsl:when test="position() + 1 != count(../bibxml:author)">, </xsl:when>
                <xsl:when test="position() + 1 = count(../bibxml:author)">, and </xsl:when>
            </xsl:choose>	
    </xsl:template>

    <xsl:template match="bibxml:editor |
                         bibxml:number | bibxml:series | bibxml:institution |
                        bibxml:organization |
                         bibxml:publisher | bibxml:school |
                         bibxml:type | bibxml:bookshelf | 
                         bibxml:annotate | bibxml:crossref |
                         bibxml:issn | bibxml:isbn |  bibxml:uri | 
                         bibxml:urn">
         <xsl:value-of select="."/>
         <xsl:if test="position() + 1 != last()">, </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:abstract">
            <xsl:if test=". != ''">
              <p><blockquote><font size="-1">
                <xsl:value-of select="."/>
              </font></blockquote></p>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:keywords">
            <xsl:choose>
                <xsl:when test="position() = 1">
                  <b>Keywords:&#160;</b>
                  <xsl:text disable-output-escaping="yes">&lt;a href="../keywords/</xsl:text>
                  <xsl:if test="not(contains(.,'*'))">
                    <xsl:value-of select="."/>
                  </xsl:if>
                  <xsl:if test="contains(.,'*')">
                    <xsl:value-of select="concat(substring-before(.,'*'),substring-after(.,'*'))"/>
                  </xsl:if>
                  <xsl:text disable-output-escaping="yes">.html"&gt;</xsl:text>
                  <xsl:value-of select="."/>
                  <xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
                </xsl:when>

                <xsl:otherwise>
                  <xsl:text disable-output-escaping="yes"> ; &lt;a href="../keywords/</xsl:text>
                  <xsl:if test="not(contains(.,'*'))">
                    <xsl:value-of select="."/>
                  </xsl:if>
                  <xsl:if test="contains(.,'*')">
                    <xsl:value-of select="concat(substring-before(.,'*'),substring-after(.,'*'))"/>
                  </xsl:if>
                  <xsl:text disable-output-escaping="yes">.html"&gt;</xsl:text>
                  <xsl:value-of select="."/>
                  <xsl:text disable-output-escaping="yes">&lt;/a&gt;</xsl:text>
                </xsl:otherwise>
            </xsl:choose>	
    </xsl:template>

    <xsl:template match="bibxml:url">
            <xsl:if test=". != ''">	
                    <a href="{.}">
                    <xsl:value-of select="."/>	
                    </a>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:pdf">
            <xsl:if test=". != ''">
                    <xsl:text> [ </xsl:text>
                    <a href="../../../{.}">.pdf</a>
                    <xsl:text> ] </xsl:text>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:ps">
            <xsl:if test=". != ''">
                    <xsl:text> [ </xsl:text>
                    <a href="../../../{.}">.ps</a>
                    <xsl:text> ] </xsl:text>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:zip">
            <xsl:if test=". != ''">
                    <xsl:text> [ </xsl:text>
                    <a href="../../../{.}">.zip</a>
                    <xsl:text> ] </xsl:text>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:medline_pmid">
            <xsl:if test=". != ''">
              <xsl:text disable-output-escaping="yes"> [ &lt;a href="http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=retrieve&amp;db=pubmed&amp;dopt=Citation&amp;list_uids=</xsl:text>
              <xsl:value-of select="."/>
              <xsl:text disable-output-escaping="yes">"&gt;PubMed&lt;/a&gt; ] </xsl:text>
            </xsl:if>
    </xsl:template>

    <xsl:template match="bibxml:web">
            <xsl:if test=". != ''"> 
                    <xsl:text> [ </xsl:text>
                    <a href="{.}">WebSite</a>
                    <xsl:text> ] </xsl:text>
            </xsl:if>
    </xsl:template>


    <!-- Do not print the following entries -->
    <xsl:template match="bibxml:category | bibxml:key"/>

</xsl:stylesheet>